oriole-test
===========

|badges| |pypi| |ci1| |ci2|

Support tdd for oriole-service. \* Free software: MIT license

.. |badges| image:: https://badges.gitter.im/zhouxiaoxiang/oriole-service.svg
   :target: https://gitter.im/oriole-service/Lobby?utm_source=share-link&utm_medium=link&utm_campaign=share-link
.. |pypi| image:: https://img.shields.io/pypi/v/oriole-test.svg
   :target: https://pypi.python.org/pypi/oriole-test
.. |ci1| image:: https://travis-ci.org/zhouxiaoxiang/oriole-test.svg?branch=master
   :target: https://travis-ci.org/zhouxiaoxiang/oriole-test
.. |ci2| image:: https://circleci.com/gh/zhouxiaoxiang/oriole-test.svg?style=svg
   :target: https://circleci.com/gh/zhouxiaoxiang/oriole-test
